<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo">
<context>
    <name>KvantumPreviewBase</name>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="14"/>
        <source>Kvantum Preview</source>
        <translation>Antaŭrigardo de Kvantum</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="29"/>
        <source>Push buttons</source>
        <translation>Prembutonoj</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="77"/>
        <source>Toggle
push
button

with
height
greater
than
width</source>
        <translation>Baskula
prem-
butono
kies alto
estas
pli granda
ol
ĝia larĝo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="95"/>
        <location filename="../../KvantumPreviewBase.ui" line="105"/>
        <source>Simple push button</source>
        <translation>Simpla prembutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="112"/>
        <location filename="../../KvantumPreviewBase.ui" line="128"/>
        <source>Toggle push button</source>
        <translation>Baskula prembutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="141"/>
        <location filename="../../KvantumPreviewBase.ui" line="152"/>
        <source>Multi-line
 push button</source>
        <translation>Plurlinia
prembutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="160"/>
        <location filename="../../KvantumPreviewBase.ui" line="180"/>
        <source>Push button
with 32px folder icon</source>
        <translation>Prembutono kun
32-bildera dosier-ikono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="210"/>
        <location filename="../../KvantumPreviewBase.ui" line="224"/>
        <source>Default
push button</source>
        <translation>Defaŭlta
prembutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="266"/>
        <source>Flat buttons</source>
        <translation>Plataj butonoj</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="279"/>
        <source>Button Box</source>
        <translation>Butonujo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="361"/>
        <source>Tool buttons</source>
        <translation>Ilbutonoj</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="369"/>
        <location filename="../../KvantumPreviewBase.ui" line="446"/>
        <source>Simple toolbutton</source>
        <translation>Simpla ilbutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="453"/>
        <location filename="../../KvantumPreviewBase.ui" line="464"/>
        <source>Multi-line
toolbutton</source>
        <translation>Plurlinia
ilbutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="472"/>
        <location filename="../../KvantumPreviewBase.ui" line="495"/>
        <source>Toggle toolbutton
with an arrow</source>
        <translation>Baskula ilbutono
havanta sagon</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="560"/>
        <location filename="../../KvantumPreviewBase.ui" line="584"/>
        <source>Toolbutton with 32px SVG icon
and text below</source>
        <translation>Ilbutono kun 32-bildera SVG-ikono
kaj suba teksto</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="605"/>
        <location filename="../../KvantumPreviewBase.ui" line="626"/>
        <source>Toolbutton with text below
and arrow</source>
        <translation>Ilbutono kun suba teksto
kaj sago</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="644"/>
        <location filename="../../KvantumPreviewBase.ui" line="665"/>
        <source>Toolbutton with icon at the side
and arrow</source>
        <translation>Ilbutono kun flanka ikono
kaj sago</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="683"/>
        <location filename="../../KvantumPreviewBase.ui" line="710"/>
        <source>Toggle toolbutton with icon,
ordinary arrow
and dropdown menu arrow</source>
        <translation>Ilbutono kun ikono,
kutima sago
kaj falmenua sago</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="515"/>
        <location filename="../../KvantumPreviewBase.ui" line="539"/>
        <source>Toolbutton with 32px PNG icon
beside text</source>
        <translation>Ilbutono kun 32-bildera PNG-ikono
apud teksto</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="402"/>
        <source>Toggle
tool
button

with
height
greater
than
width</source>
        <translation>Baskula
ilbutono
kies alto
estas
pli granda
ol
ĝia larĝo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="791"/>
        <source>Auto-raise</source>
        <translation>Aŭtoaltigo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="812"/>
        <source>Radio/Check buttons</source>
        <translation>Radio/mark-butonoj</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="833"/>
        <location filename="../../KvantumPreviewBase.ui" line="846"/>
        <source>Simple radio button</source>
        <translation>Simpla radiobutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="856"/>
        <location filename="../../KvantumPreviewBase.ui" line="867"/>
        <source>Multi-line
radio button</source>
        <translation>Plurlinia
radiobutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="878"/>
        <location filename="../../KvantumPreviewBase.ui" line="904"/>
        <source>Radio button with 32px SVG icon</source>
        <translation>Radiobutono kun 32-bildera SVG-ikono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="927"/>
        <location filename="../../KvantumPreviewBase.ui" line="940"/>
        <source>Simple check box</source>
        <translation>Simpla markbutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="950"/>
        <location filename="../../KvantumPreviewBase.ui" line="961"/>
        <source>Multi-line
check box</source>
        <translation>Plurlinia
markbutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="969"/>
        <location filename="../../KvantumPreviewBase.ui" line="982"/>
        <source>Tri-state check box</source>
        <translation>Tristata markbutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="992"/>
        <location filename="../../KvantumPreviewBase.ui" line="1006"/>
        <source>Check box with icon</source>
        <translation>Markbutono kun ikono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1062"/>
        <source>Combos/Spins/Inputs</source>
        <translation>Fallistiloj/Ŝpinbutonoj/Enigiloj</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1096"/>
        <location filename="../../KvantumPreviewBase.ui" line="1182"/>
        <location filename="../../KvantumPreviewBase.ui" line="1251"/>
        <location filename="../../KvantumPreviewBase.ui" line="1365"/>
        <location filename="../../KvantumPreviewBase.ui" line="1437"/>
        <location filename="../../KvantumPreviewBase.ui" line="1495"/>
        <source>Frameless (no difference)</source>
        <translation>Senkadra (neniu diferenco)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1107"/>
        <location filename="../../KvantumPreviewBase.ui" line="1146"/>
        <source>Standard combo box</source>
        <translation>Norma fallistilo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1116"/>
        <location filename="../../KvantumPreviewBase.ui" line="1155"/>
        <source>Standard combo box 1</source>
        <translation>Norma fallistilo 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1124"/>
        <location filename="../../KvantumPreviewBase.ui" line="1160"/>
        <source>Standard combo box 2</source>
        <translation>Norma fallistilo 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1129"/>
        <location filename="../../KvantumPreviewBase.ui" line="1165"/>
        <source>Standard combo box 3</source>
        <translation>Norma fallistilo 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1134"/>
        <location filename="../../KvantumPreviewBase.ui" line="1170"/>
        <source>Standard combo box 4</source>
        <translation>Norma fallistilo 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1191"/>
        <location filename="../../KvantumPreviewBase.ui" line="1260"/>
        <location filename="../../KvantumPreviewBase.ui" line="1374"/>
        <location filename="../../KvantumPreviewBase.ui" line="1446"/>
        <source>Frameless 1</source>
        <translation>Senkadra 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1196"/>
        <location filename="../../KvantumPreviewBase.ui" line="1265"/>
        <location filename="../../KvantumPreviewBase.ui" line="1379"/>
        <location filename="../../KvantumPreviewBase.ui" line="1451"/>
        <source>Frameless 2</source>
        <translation>Senkadra 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1201"/>
        <location filename="../../KvantumPreviewBase.ui" line="1270"/>
        <location filename="../../KvantumPreviewBase.ui" line="1384"/>
        <location filename="../../KvantumPreviewBase.ui" line="1456"/>
        <source>Frameless 3</source>
        <translation>Senkadra 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1206"/>
        <location filename="../../KvantumPreviewBase.ui" line="1275"/>
        <location filename="../../KvantumPreviewBase.ui" line="1389"/>
        <location filename="../../KvantumPreviewBase.ui" line="1461"/>
        <source>Frameless 4</source>
        <translation>Senkadra 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1211"/>
        <location filename="../../KvantumPreviewBase.ui" line="1394"/>
        <source>Frameless 5</source>
        <translation>Senkadra 5</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1216"/>
        <location filename="../../KvantumPreviewBase.ui" line="1399"/>
        <source>Frameless 6</source>
        <translation>Senkadra 6</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1221"/>
        <location filename="../../KvantumPreviewBase.ui" line="1404"/>
        <source>Frameless 7</source>
        <translation>Senkadra 7</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1226"/>
        <location filename="../../KvantumPreviewBase.ui" line="1409"/>
        <source>Frameless 8</source>
        <translation>Senkadra 8</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1231"/>
        <location filename="../../KvantumPreviewBase.ui" line="1414"/>
        <source>Frameless 9</source>
        <translation>Senkadra 9</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1236"/>
        <location filename="../../KvantumPreviewBase.ui" line="1419"/>
        <source>Frameless 10</source>
        <translation>Senkadra 10</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1287"/>
        <location filename="../../KvantumPreviewBase.ui" line="1326"/>
        <source>Editable combo box</source>
        <translation>Redaktebla fallistilo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1296"/>
        <location filename="../../KvantumPreviewBase.ui" line="1335"/>
        <source>Editable combo box 1</source>
        <translation>Redaktebla fallistilo 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1301"/>
        <location filename="../../KvantumPreviewBase.ui" line="1340"/>
        <source>Editable combo box 2</source>
        <translation>Redaktebla fallistilo 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1306"/>
        <location filename="../../KvantumPreviewBase.ui" line="1345"/>
        <source>Editable combo box 3</source>
        <translation>Redaktebla fallistilo 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1311"/>
        <location filename="../../KvantumPreviewBase.ui" line="1350"/>
        <source>Editable combo box 4</source>
        <translation>Redaktebla fallistilo 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1469"/>
        <location filename="../../KvantumPreviewBase.ui" line="1482"/>
        <source>Line-edit</source>
        <translation>Liniredaktilo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1561"/>
        <source>Sliders/Scrolls/Progress/Dial</source>
        <translation>Ŝoviloj/Rulumiloj/Progresiloj</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2118"/>
        <source>Containers</source>
        <translation>Ujoj</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2139"/>
        <source>Header 1</source>
        <translation>Ĉapo 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2148"/>
        <source>Header 2</source>
        <translation>Ĉapo 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2156"/>
        <source>Header 3</source>
        <translation>Ĉapo 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2161"/>
        <source>3rd Item</source>
        <translation>3-a Ero</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2169"/>
        <source>2nd Item</source>
        <translation>2-a Ero</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2173"/>
        <location filename="../../KvantumPreviewBase.ui" line="2209"/>
        <source>2nd Child</source>
        <translation>2-a Ido</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2178"/>
        <location filename="../../KvantumPreviewBase.ui" line="2214"/>
        <source>1st Child</source>
        <translation>1-a Ido</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2184"/>
        <source>1st Item</source>
        <translation>1-a Ero</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2204"/>
        <source>3rd Child</source>
        <translation>3-a Ido</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2462"/>
        <source>Row 0</source>
        <translation>Vico 0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2467"/>
        <source>Row 1</source>
        <translation>Vico 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2472"/>
        <source>Column 0</source>
        <translation>kolumno 0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2480"/>
        <source>Column 1</source>
        <translation>kolumno 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2485"/>
        <source>0-0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2493"/>
        <source>0-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2501"/>
        <source>1-0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2509"/>
        <source>1-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2191"/>
        <location filename="../../KvantumPreviewBase.ui" line="2194"/>
        <source>Editable</source>
        <translation>Redaktebla</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2221"/>
        <source>Non-Editable</source>
        <translation>Neredaktebla</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2229"/>
        <source>Subwindow</source>
        <translation>Subfenestro</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2276"/>
        <source>Panel frame</source>
        <translation>Panelkadro</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2295"/>
        <location filename="../../KvantumPreviewBase.ui" line="2436"/>
        <location filename="../../KvantumPreviewBase.ui" line="2528"/>
        <source>GroupBox</source>
        <translation>Grupzono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2315"/>
        <location filename="../../KvantumPreviewBase.ui" line="2367"/>
        <location filename="../../KvantumPreviewBase.ui" line="2661"/>
        <location filename="../../KvantumPreviewBase.ui" line="2738"/>
        <location filename="../../KvantumPreviewBase.ui" line="2786"/>
        <source>Tab 1</source>
        <translation>Folio 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2321"/>
        <source>Page 1 (disabled)</source>
        <translation>Paĝo 1 (malvalidigita)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2333"/>
        <location filename="../../KvantumPreviewBase.ui" line="2381"/>
        <location filename="../../KvantumPreviewBase.ui" line="2679"/>
        <location filename="../../KvantumPreviewBase.ui" line="2752"/>
        <location filename="../../KvantumPreviewBase.ui" line="2800"/>
        <source>Tab 2</source>
        <translation>Folio 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2339"/>
        <source>Page 2 (disabled)</source>
        <translation>Paĝo 2 (malvalidigita)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2373"/>
        <location filename="../../KvantumPreviewBase.ui" line="2566"/>
        <location filename="../../KvantumPreviewBase.ui" line="2621"/>
        <location filename="../../KvantumPreviewBase.ui" line="2744"/>
        <location filename="../../KvantumPreviewBase.ui" line="2792"/>
        <source>Page 1</source>
        <translation>Paĝo 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2387"/>
        <location filename="../../KvantumPreviewBase.ui" line="2594"/>
        <location filename="../../KvantumPreviewBase.ui" line="2634"/>
        <location filename="../../KvantumPreviewBase.ui" line="2685"/>
        <location filename="../../KvantumPreviewBase.ui" line="2758"/>
        <location filename="../../KvantumPreviewBase.ui" line="2806"/>
        <source>Page 2</source>
        <translation>Paĝo 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2411"/>
        <source>Stack widget (page1)</source>
        <translation>Stakilo (paĝo 1)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2425"/>
        <source>Stack Widget (page2)</source>
        <translation>Stakilo (paĝo 2)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2442"/>
        <source>Group box</source>
        <translation>Grupzono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2520"/>
        <source>Dock Widget</source>
        <translation>Doko</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2537"/>
        <source>Checkable group box</source>
        <translation>Markebla grupzono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2572"/>
        <source>Tool Box</source>
        <translation>Ilujo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2667"/>
        <source>Document mode</source>
        <translation>Dokumenta moduso</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2705"/>
        <source>Box frame</source>
        <translation>Skatolkadro</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2835"/>
        <source>&amp;File</source>
        <translation>&amp;Dosiero</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2839"/>
        <source>&amp;Submenu</source>
        <translation>&amp;Submenuo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2859"/>
        <source>toolBar</source>
        <translation>Ilbreto</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2879"/>
        <source>toolBar_2</source>
        <translation>Ilbreto_2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2901"/>
        <source>&amp;Quit</source>
        <translation>&amp;Eliri</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2904"/>
        <source>Quit</source>
        <translation>Eliri</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2907"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2915"/>
        <source>&amp;Checkbox</source>
        <translation>&amp;Markbutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2928"/>
        <source>Toggle Layout</source>
        <translation>Inversi la aranĝon</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2931"/>
        <source>Toggle layout direction</source>
        <translation>Inversi la direkton de la aranĝo</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2943"/>
        <source>&amp;Doc Mode</source>
        <translation>&amp;Dokumenta moduso</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2946"/>
        <source>Show tabs in the document mode</source>
        <translation>Montru la foliojn laŭ la dokumenta moduso</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2958"/>
        <source>Menu Button</source>
        <translation>Menubutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2961"/>
        <source>Hold pressed to show a menu</source>
        <translation>Tenu premante por montri menuon</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2972"/>
        <source>C&amp;heckbox</source>
        <translation>M&amp;arkbutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2980"/>
        <source>&amp;Radio button</source>
        <translation>&amp;Radiobutono</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2988"/>
        <source>Radio &amp;button</source>
        <translation>Radi&amp;obutono</translation>
    </message>
</context>
</TS>
